;; Generated package description from git-modes.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "git-modes" "1.4.8.0.20260511.154926" "Major modes for editing Git configuration files" '((emacs "26.1") (compat "30.1")) :commit "9fc447e409ad78dd11ae7f9c5436ee1631380b3f" :authors '(("Sebastian Wiesner" . "lunaryorn@gmail.com") ("Rüdiger Sonderfeld" . "ruediger@c-plusplus.net") ("Jonas Bernoulli" . "emacs.git-modes@jonas.bernoulli.dev")) :maintainer '("Jonas Bernoulli" . "emacs.git-modes@jonas.bernoulli.dev") :keywords '("convenience" "vc" "git") :url "https://github.com/magit/git-modes")
